from setuptools import setup

setup(name='distributions_WC',
      version='0.1',
      description='Gaussian and binomial distributions',
      packages=['distributions_WC'],
      author_email='wbchristerson@gmail.com',
      zip_safe=False)
